@@ -1,7 +1,7 @@
 import functools
 import json
 import logging
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union  # pylint: disable=unused-import
+from typing import Any, Dict, Optional, Tuple
 
 import backoff
 import requests
@@ -21,6 +21,7 @@ def my_backoff(function):
     """
     HTTP Status Codeが429 or 5XXのときはリトライする. 最大5分間リトライする。
     """
+
     @functools.wraps(function)
     def wrapped(*args, **kwargs):
         def fatal_code(e):
@@ -58,8 +59,13 @@ def my_backoff(function):
                 # リトライする
                 return False
 
-        return backoff.on_exception(backoff.expo, requests.exceptions.RequestException, jitter=backoff.full_jitter,
-                                    max_time=300, giveup=fatal_code)(function)(*args, **kwargs)
+        return backoff.on_exception(
+            backoff.expo,
+            requests.exceptions.RequestException,
+            jitter=backoff.full_jitter,
+            max_time=300,
+            giveup=fatal_code,
+        )(function)(*args, **kwargs)
 
     return wrapped
 
@@ -73,6 +79,7 @@ class AnnofabApi(AbstractAnnofabApi):
         login_password: AnnoFabにログインするときのパスワード
         endpoint_url: AnnoFab APIのエンドポイント。
     """
+
     def __init__(self, login_user_id: str, login_password: str, endpoint_url: str = DEFAULT_ENDPOINT_URL):
 
         if not login_user_id or not login_password:
@@ -95,18 +102,23 @@ class AnnofabApi(AbstractAnnofabApi):
         requestsモジュールのauthに渡す情報。
         http://docs.python-requests.org/en/master/user/advanced/#custom-authentication
         """
+
         def __init__(self, id_token: str):
             self.id_token = id_token
 
         def __call__(self, req):
-            req.headers['Authorization'] = self.id_token
+            req.headers["Authorization"] = self.id_token
             return req
 
     #########################################
     # Private Method
     #########################################
-    def _create_kwargs(self, params: Optional[Dict[str, Any]] = None, headers: Optional[Dict[str, Any]] = None,
-                       request_body: Optional[Any] = None) -> Dict[str, Any]:
+    def _create_kwargs(
+        self,
+        params: Optional[Dict[str, Any]] = None,
+        headers: Optional[Dict[str, Any]] = None,
+        request_body: Optional[Any] = None,
+    ) -> Dict[str, Any]:
         """
         requestsモジュールのget,...メソッドに渡すkwargsを生成する。
 
@@ -129,21 +141,21 @@ class AnnofabApi(AbstractAnnofabApi):
                     new_params[key] = value
 
         kwargs: Dict[str, Any] = {
-            'params': new_params,
-            'headers': headers,
+            "params": new_params,
+            "headers": headers,
         }
         if self.token_dict is not None:
-            kwargs.update({'auth': self.__MyToken(self.token_dict['id_token'])})
+            kwargs.update({"auth": self.__MyToken(self.token_dict["id_token"])})
 
         if request_body is not None:
             if isinstance(request_body, (dict, list)):
-                kwargs.update({'json': request_body})
+                kwargs.update({"json": request_body})
 
             elif isinstance(request_body, str):
-                kwargs.update({'data': request_body.encode("utf-8")})
+                kwargs.update({"data": request_body.encode("utf-8")})
 
             else:
-                kwargs.update({'data': request_body})
+                kwargs.update({"data": request_body})
 
         return kwargs
 
@@ -160,15 +172,15 @@ class AnnofabApi(AbstractAnnofabApi):
 
         """
 
-        content_type = response.headers['Content-Type']
+        content_type = response.headers["Content-Type"]
         # `Content-Type: application/json;charset=utf-8`などcharsetが含まれている場合にも対応できるようにする。
-        tokens = content_type.split(';')
+        tokens = content_type.split(";")
         media_type = tokens[0].strip()
 
-        if media_type == 'application/json':
+        if media_type == "application/json":
             content = response.json() if len(response.content) != 0 else {}
 
-        elif media_type.find('text/') >= 0:
+        elif media_type.find("text/") >= 0:
             content = response.text
 
         else:
@@ -177,9 +189,14 @@ class AnnofabApi(AbstractAnnofabApi):
         return content
 
     @my_backoff
-    def _request_wrapper(self, http_method: str, url_path: str, query_params: Optional[Dict[str, Any]] = None,
-                         header_params: Optional[Dict[str, Any]] = None,
-                         request_body: Optional[Any] = None) -> Tuple[Any, requests.Response]:
+    def _request_wrapper(
+        self,
+        http_method: str,
+        url_path: str,
+        query_params: Optional[Dict[str, Any]] = None,
+        header_params: Optional[Dict[str, Any]] = None,
+        request_body: Optional[Any] = None,
+    ) -> Tuple[Any, requests.Response]:
         """
         HTTP　Requestを投げて、Reponseを返す。
 
@@ -195,10 +212,10 @@ class AnnofabApi(AbstractAnnofabApi):
             application/jsonならDict型, text/*ならばstr型, それ以外ならばbite型。
 
         """
-        if url_path.startswith("/labor-control/") or url_path.startswith("/internal/"):
+        if url_path.startswith("/labor-control") or url_path.startswith("/internal/"):
             url = f"{self.endpoint_url}/api{url_path}"
         else:
-            url = f'{self.url_prefix}{url_path}'
+            url = f"{self.url_prefix}{url_path}"
 
         kwargs = self._create_kwargs(query_params, header_params, request_body)
 
@@ -212,7 +229,7 @@ class AnnofabApi(AbstractAnnofabApi):
 
         _log_error_response(logger, response)
 
-        response.encoding = 'utf-8'
+        response.encoding = "utf-8"
         _raise_for_status(response)
 
         content = self._response_to_content(response)
@@ -230,8 +247,8 @@ class AnnofabApi(AbstractAnnofabApi):
             Tuple[Content, Response)
 
         """
-        url_path = f'/internal/projects/{project_id}/sign-headers'
-        http_method = 'GET'
+        url_path = f"/internal/projects/{project_id}/sign-headers"
+        http_method = "GET"
         keyword_params: Dict[str, Any] = {}
         return self._request_wrapper(http_method, url_path, **keyword_params)
 
@@ -247,6 +264,7 @@ class AnnofabApi(AbstractAnnofabApi):
             Response
 
         """
+
         def request(cookies):
             kwargs = {"cookies": cookies}
             return self.session.get(url, **kwargs)
@@ -282,7 +300,7 @@ class AnnofabApi(AbstractAnnofabApi):
             Tuple[Token, requests.Response]
 
         """
-        login_info = {'user_id': self.login_user_id, 'password': self.login_password}
+        login_info = {"user_id": self.login_user_id, "password": self.login_password}
 
         url = f"{self.url_prefix}/login"
         response = self.session.post(url, json=login_info)
@@ -313,7 +331,7 @@ class AnnofabApi(AbstractAnnofabApi):
             return None
 
         request_body = self.token_dict
-        content, response = self._request_wrapper('POST', '/logout', request_body=request_body)
+        content, response = self._request_wrapper("POST", "/logout", request_body=request_body)
         self.token_dict = None
         return content, response
 
@@ -332,8 +350,8 @@ class AnnofabApi(AbstractAnnofabApi):
             logger.info("You are not logged in.")
             return None
 
-        request_body = {'refresh_token': self.token_dict['refresh_token']}
-        content, response = self._request_wrapper('POST', '/refresh-token', request_body=request_body)
+        request_body = {"refresh_token": self.token_dict["refresh_token"]}
+        content, response = self._request_wrapper("POST", "/refresh-token", request_body=request_body)
         self.token_dict = content
         return content, response
 
@@ -353,10 +371,10 @@ class AnnofabApi(AbstractAnnofabApi):
 
 
         """
-        url_path = f'/labor-control'
-        http_method = 'GET'
+        url_path = f"/labor-control"
+        http_method = "GET"
         keyword_params: Dict[str, Any] = {
-            'query_params': query_params,
+            "query_params": query_params,
         }
         return self._request_wrapper(http_method, url_path, **keyword_params)
 
@@ -372,10 +390,10 @@ class AnnofabApi(AbstractAnnofabApi):
 
 
         """
-        url_path = f'/labor-control'
-        http_method = 'PUT'
+        url_path = f"/labor-control"
+        http_method = "PUT"
         keyword_params: Dict[str, Any] = {
-            'request_body': request_body,
+            "request_body": request_body,
         }
         return self._request_wrapper(http_method, url_path, **keyword_params)
 
@@ -391,7 +409,7 @@ class AnnofabApi(AbstractAnnofabApi):
 
 
         """
-        url_path = f'/labor-control/{data_id}'
-        http_method = 'DELETE'
+        url_path = f"/labor-control/{data_id}"
+        http_method = "DELETE"
         keyword_params: Dict[str, Any] = {}
         return self._request_wrapper(http_method, url_path, **keyword_params)
