@@ -14,7 +14,6 @@ from typing import Any, Dict, List, NewType, Optional, Tuple, Union  # pylint: d
 
 from dataclasses_json import dataclass_json
 
-from annofabapi.dataclass.organization import OrganizationSummary
 from annofabapi.models import AccountAuthority, OrganizationMemberRole, OrganizationMemberStatus, PricePlan
 
 
@@ -24,8 +23,9 @@ class MyOrganization:
     """
     
     """
+
     organization_id: Optional[str]
-    """"""
+    """組織ID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
     name: Optional[str]
     """"""
@@ -36,7 +36,7 @@ class MyOrganization:
     price_plan: Optional[PricePlan]
     """"""
 
-    summary: Optional[OrganizationSummary]
+    summary: Optional[Dict[str, Any]]
     """"""
 
     created_datetime: Optional[str]
@@ -58,6 +58,7 @@ class MyAccount:
     """
     
     """
+
     account_id: str
     """"""
 
